*************************
Astropop Documentation
*************************

.. warning::
    Documentation outdated. Do not use it. We are rewriting it!

.. TODO::
    Insert detailed install instructions here

***************
For Users
***************

For end users that just want to reduce their data using ASTROPOP, you can follow our reduction examples on this documentations:

.. toctree::
    :maxdepth: 1

    ipynb/diy_reduction_script.ipynb


API level documentation and technical details for each module you can find in specific documentation listed bellow.

.. toctree::
    :maxdepth: 1

    logger
    framedata
    memmap
    pipelines
    fits_utils
    py_utils
    catalogs
    physical
    testing
    imarith
    ccdprocessing
    registering
    photometry
    polarimetry
    astrometry


***************
Developer Docs
***************

.. toctree::
    :maxdepth: 1

    dev/pixel_convention

***************
API
***************

.. toctree::
    :maxdepth: 1

    api

***************
Index
***************

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
